/*
 * Global variables
 * Copyright (C) 2001 Jan Oberlnder <mindriot@gmx.net>
 *
 * This file is part of netload_applet.
 *
 * netload_applet is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: globals.c,v 1.2 2001/10/04 23:17:54 mindriot Exp $
 */

#include <config.h>
#include "netload_applet.h"

/*
 * The display scheme settings.
 */
DisplayScheme display_scheme;

DisplayScheme default_display_scheme = {
	rx_load_font: NULL,
	tx_load_font: NULL,
	max_load_font: NULL,
	dev_font: NULL,

	rx_load_font_name: NULL,
	tx_load_font_name: NULL,
	max_load_font_name: NULL,
	dev_font_name: NULL,

	background_color: {red: 0x0000, green: 0x0000, blue: 0x0000},
	rx_graph_color: {red: 0x0000, green: 0xffff, blue: 0x0000},
	tx_graph_color: {red: 0xffff, green: 0x0000, blue: 0x0000},
	rx_avg_color: {red: 0x0000, green: 0x8000, blue: 0x0000},
	tx_avg_color: {red: 0x8000, green: 0x0000, blue: 0x0000},
	rx_load_color: {red: 0xffff, green: 0xffff, blue: 0xffff},
	tx_load_color: {red: 0xffff, green: 0xffff, blue: 0xffff},
	max_load_color: {red: 0x0000, green: 0x8000, blue: 0x0000},
	dev_color: {red: 0xffff, green: 0xffff, blue: 0xffff},
	top_edge_color: {red: 0x2000, green: 0x2000, blue: 0x2000},
	bottom_edge_color: {red: 0xe000, green: 0xe000, blue: 0xe000},

	rx_load_position: POS_MIDDLE | POS_CENTER,
	tx_load_position: POS_MIDDLE | POS_CENTER,
	max_load_position: POS_TOP | POS_LEFT,
	dev_position: POS_BOTTOM | POS_LEFT,

	show_rx_graph: TRUE,
	show_tx_graph: TRUE,
	show_rx_avg: TRUE,
	show_tx_avg: FALSE,
	show_rx_load: TRUE,
	show_tx_load: FALSE,
	show_max_load: TRUE,
	show_dev: TRUE,

	width: 120,
	height: 48,
	fixed_width: TRUE,
	fixed_height: FALSE,

	rx_graph_style: GRAPH_BARCHART,
	tx_graph_style: GRAPH_LINECHART,
	graph_order: TX_ON_TOP,

	device: NULL,
	timeout: 1000
};

/*
 * applet widget
 */
GtkWidget *applet;

/*
 * drawable area in panel
 */
GtkWidget *draw = NULL;

/*
 * our panel's current size. Only interesting for Gnome >= 1.2.
 */
#ifdef HAVE_PANEL_PIXEL_SIZE
int panel_size = PIXEL_SIZE_STANDARD;
#endif

/*
 * Graphics context
 */
GdkGC *gc = NULL;

/*
 * Data counts
 */
guint32 *rx_byte_counts = NULL,
        *tx_byte_counts = NULL,
	*rx_delta_counts = NULL,
	*tx_delta_counts = NULL,
	*rx_values = NULL,
	*tx_values = NULL,
	rx_average = 0,
	tx_average = 0,
	largest = 0;

/*
 * Last display width
 */
guint32 oldwidth = 0;

/*
 * Timeout handler ID
 */
guint timeout_id;

/*
 * List of available net devices
 */
gchar **device_list;

/*
 * The Preferences dialog
 */
gboolean pref_window_visible = FALSE;
GtkWidget *pref_dialog = NULL;

/*
 * Interface down?
 */
gboolean iface_down = FALSE;

/*
 * All dialog elements
 */
GtkWidget *pref_window;
GtkWidget *main_box;
GtkWidget *notebook;
GtkWidget *nbox1;
GtkWidget *info1;
GtkWidget *nseparator1;
GtkWidget *size_table;
GtkWidget *fixed_width;
GtkWidget *fixed_height;
GtkWidget *width_label;
GtkWidget *height_label;
GtkObject *width_spinbutton_adj;
GtkWidget *width_spinbutton;
GtkObject *height_spinbutton_adj;
GtkWidget *height_spinbutton;
GtkWidget *panel_table;
GtkWidget *background_label;
GtkWidget *topleft_label;
GtkWidget *bottomright_label;
GtkWidget *monitor_label;
GtkWidget *refresh_label;
GtkWidget *background_color_picker;
GtkWidget *top_edge_color_picker;
GtkWidget *bottom_edge_color_picker;
GtkObject *timeout_spinbutton_adj;
GtkWidget *timeout_spinbutton;
GtkWidget *device_selector;
GtkWidget *device_selector_menu;
GtkWidget *glade_menuitem;
GtkWidget *nlabel1;
GtkWidget *nbox2;
GtkWidget *info2;
GtkWidget *nseparator2;
GtkWidget *graph_hbox;
GtkWidget *rx_frame;
GtkWidget *rx_vbox;
GtkWidget *show_rx_graph_button;
GSList *top_group = NULL;
GtkWidget *rx_on_top_button;
GtkWidget *show_rx_avg_load_button;
GtkWidget *rx_style_table;
GtkWidget *rx_graph_style_selector;
GtkWidget *rx_graph_style_selector_menu;
GtkWidget *rx_graph_color_label;
GtkWidget *rx_avg_load_color_label;
GtkWidget *rx_graph_style_label;
GtkWidget *rx_graph_color_picker;
GtkWidget *rx_avg_load_color_picker;
GtkWidget *tx_frame;
GtkWidget *tx_vbox;
GtkWidget *show_tx_graph_button;
GtkWidget *tx_on_top_button;
GtkWidget *show_tx_avg_load_button;
GtkWidget *tx_style_table;
GtkWidget *tx_graph_style_selector;
GtkWidget *tx_graph_style_selector_menu;
GtkWidget *tx_graph_color_label;
GtkWidget *tx_graph_style_label;
GtkWidget *tx_avg_load_color_label;
GtkWidget *tx_graph_color_picker;
GtkWidget *tx_avg_load_color_picker;
GtkWidget *nlabel2;
GtkWidget *nbox3;
GtkWidget *info3;
GtkWidget *nseparator3;
GtkWidget *label_table;
GtkWidget *vpos_label;
GtkWidget *hpos_label;
GtkWidget *color_label;
GtkWidget *font_label;
GtkWidget *tx_rate_button;
GtkWidget *rx_rate_button;
GtkWidget *max_rate_button;
GtkWidget *device_name_button;
GtkWidget *rx_vpos_selector;
GtkWidget *rx_vpos_selector_menu;
GtkWidget *tx_vpos_selector;
GtkWidget *tx_vpos_selector_menu;
GtkWidget *max_vpos_selector;
GtkWidget *max_vpos_selector_menu;
GtkWidget *device_vpos_selector;
GtkWidget *device_vpos_selector_menu;
GtkWidget *rx_hpos_selector;
GtkWidget *rx_hpos_selector_menu;
GtkWidget *tx_hpos_selector;
GtkWidget *tx_hpos_selector_menu;
GtkWidget *max_hpos_selector;
GtkWidget *max_hpos_selector_menu;
GtkWidget *device_hpos_selector;
GtkWidget *device_hpos_selector_menu;
GtkWidget *rx_color_picker;
GtkWidget *tx_color_picker;
GtkWidget *max_color_picker;
GtkWidget *device_color_picker;
GtkWidget *rx_font_picker;
GtkWidget *tx_font_picker;
GtkWidget *max_font_picker;
GtkWidget *device_font_picker;
GtkWidget *item_label;
GtkWidget *nlabel3;
GtkWidget *main_separator;
GtkWidget *buttonbox;
guint load_theme_button_key;
GtkWidget *load_theme_button;
guint save_theme_button_key;
GtkWidget *save_theme_button;
GtkWidget *apply_button;
GtkWidget *ok_button;
GtkWidget *close_button;
GtkAccelGroup *accel_group;
GtkTooltips *tooltips;

