/*
 * NetLoad Applet main file
 * Copyright (C) 2001 Jan Oberlnder <mindriot@gmx.net>
 *
 * This file is part of netload_applet.
 *
 * netload_applet is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: main.c,v 1.2 2001/10/04 23:17:54 mindriot Exp $
 */

#include <config.h>

#include <stdio.h>
#include <string.h>
#include <gnome.h>
#include <applet-widget.h>
#include <libgnome/gnome-i18n.h>

#include "main.h"

void
draw_rx_graph(void)
{
	guint i;

	gdk_gc_set_foreground(gc, &display_scheme.rx_graph_color);
	if (display_scheme.rx_graph_style == GRAPH_BARCHART) {
		for (i = 0; i < display_scheme.width-2; i++)
			gdk_draw_line(draw->window, gc, i+1, display_scheme.height-2, i+1, display_scheme.height-2-rx_values[i]);
	} else {
		for (i = 1; i < display_scheme.width-2; i++)
			gdk_draw_line(draw->window, gc, i, display_scheme.height-2-rx_values[i-1], i+1, display_scheme.height-2-rx_values[i]);
	}
}

void
draw_tx_graph(void)
{
	guint i;

	gdk_gc_set_foreground(gc, &display_scheme.tx_graph_color);
	if (display_scheme.tx_graph_style == GRAPH_BARCHART) {
		for (i = 0; i < display_scheme.width-2; i++)
			gdk_draw_line(draw->window, gc, i+1, display_scheme.height-2, i+1, display_scheme.height-2-tx_values[i]);
	} else {
		for (i = 1; i < display_scheme.width-2; i++)
			gdk_draw_line(draw->window, gc, i, display_scheme.height-2-tx_values[i-1], i+1, display_scheme.height-2-tx_values[i]);
	}
}

void
draw_text(char *text, GdkFont *font, ItemPosition pos)
{
	uint w, h, x=0, y=0, l;

	w = gdk_string_width(font, text);
	h = gdk_string_height(font, text);
	l = strlen(text);

	switch (pos & POS_VERT) {
	case POS_TOP:
		y = h + 2;
		break;
	case POS_MIDDLE:
		y = (display_scheme.height / 2) + (h / 2);
		break;
	case POS_BOTTOM:
		y = display_scheme.height - 2;
		break;
	default:
		g_assert_not_reached();
	}
	switch (pos & POS_HORIZ) {
	case POS_LEFT:
		x = 2;
		break;
	case POS_CENTER:
		x = (display_scheme.width / 2) - (w / 2);
		break;
	case POS_RIGHT:
		x = display_scheme.width - 2 - w;
		break;
	default:
		g_assert_not_reached();
	}

	gdk_draw_text(draw->window, font, gc,
		      x, y, text, l);
}

void
draw_values (void)
{
	gchar *text = NULL;
	guint32 rate;

	g_assert (draw->window != NULL);

	DEBUG_MESSAGE ("draw_values: drawing graph.\n");

	/*
	 * paint background and frame
	 */
	gdk_gc_set_foreground(gc, &display_scheme.background_color);
	gdk_draw_rectangle(draw->window, gc, TRUE, 0, 0, display_scheme.width-1, display_scheme.height-1);
	gdk_gc_set_foreground(gc, &display_scheme.top_edge_color);
	gdk_draw_line(draw->window, gc, 0, 0, display_scheme.width-1, 0);
	gdk_draw_line(draw->window, gc, 0, 0, 0, display_scheme.height-1);
	gdk_gc_set_foreground(gc, &display_scheme.bottom_edge_color);
	gdk_draw_line(draw->window, gc, display_scheme.width-1, 0, display_scheme.width-1, display_scheme.height-1);
	gdk_draw_line(draw->window, gc, 0, display_scheme.height-1, display_scheme.width-1, display_scheme.height-1);

	/*
	 * paint rx/tx graph, average lines
	 */
	if (display_scheme.graph_order == RX_ON_TOP) {
		if (display_scheme.show_tx_graph) draw_tx_graph();
		if (display_scheme.show_rx_graph) draw_rx_graph();
		if (display_scheme.show_tx_avg) {
			gdk_gc_set_foreground(gc, &display_scheme.tx_avg_color);
			gdk_draw_line(draw->window, gc, 1, display_scheme.height-2-tx_average,
				      display_scheme.width-2, display_scheme.height-2-tx_average);
		}
		if (display_scheme.show_rx_avg) {
			gdk_gc_set_foreground(gc, &display_scheme.rx_avg_color);
			gdk_draw_line(draw->window, gc, 1, display_scheme.height-2-rx_average,
				      display_scheme.width-2, display_scheme.height-2-rx_average);
		}
	} else {
		if (display_scheme.show_rx_graph) draw_rx_graph();
		if (display_scheme.show_tx_graph) draw_tx_graph();
		if (display_scheme.show_rx_avg) {
			gdk_gc_set_foreground(gc, &display_scheme.rx_avg_color);
			gdk_draw_line(draw->window, gc, 1, display_scheme.height-2-rx_average,
				      display_scheme.width-2, display_scheme.height-2-rx_average);
		}
		if (display_scheme.show_tx_avg) {
			gdk_gc_set_foreground(gc, &display_scheme.tx_avg_color);
			gdk_draw_line(draw->window, gc, 1, display_scheme.height-2-tx_average,
				      display_scheme.width-2, display_scheme.height-2-tx_average);
		}
	}

	/*
	 * print max rate
	 */
	if (display_scheme.show_max_load) {
		rate = largest * 1000 / display_scheme.timeout;
		gdk_gc_set_foreground(gc, &display_scheme.max_load_color);
		if (rate > 1023)
			text = g_strdup_printf("%.1f K", (double) rate / 1024.0);
		else
			text = g_strdup_printf("%i B", rate);
		draw_text (text, display_scheme.max_load_font, display_scheme.max_load_position);
		g_free(text);
	}

	/*
	 * print receive rate
	 */
	if (display_scheme.show_rx_load) {
		rate = rx_delta_counts[display_scheme.width-3] * 1000 / display_scheme.timeout;
		gdk_gc_set_foreground(gc, &display_scheme.rx_load_color);
		if (rate > 1023)
			text = g_strdup_printf("%.1f K", (double) rate / 1024.0);
		else
			text = g_strdup_printf("%i B", rate);
		draw_text (text, display_scheme.rx_load_font, display_scheme.rx_load_position);
		g_free(text);
	}

	/*
	 * print transmit rate
	 */
	if (display_scheme.show_tx_load) {
		rate = tx_delta_counts[display_scheme.width-3] * 1000 / display_scheme.timeout;
		gdk_gc_set_foreground(gc, &display_scheme.tx_load_color);
		if (rate > 1023)
			text = g_strdup_printf("%.1f K", (double) rate / 1024.0);
		else
			text = g_strdup_printf("%i B", rate);
		draw_text (text, display_scheme.tx_load_font, display_scheme.tx_load_position);
		g_free(text);
	}

	/*
	 * print device name
	 */
	if (display_scheme.show_dev) {
		gdk_gc_set_foreground(gc, &display_scheme.dev_color);
		if (iface_down) {
			if (display_scheme.device == NULL) {
				text = g_strdup_printf("(?)");
			} else {
				text = g_strdup_printf("(%s)", display_scheme.device);
			}
		} else {
			text = g_strdup (display_scheme.device);
		}
		draw_text (text, display_scheme.dev_font, display_scheme.dev_position);
		g_free (text);
	}
}

int
main(int argc, char *argv[])
{
#if HOST==BSD
	DEBUG_MESSAGE ("netload_applet v" VERSION ", BSD, started.\n");
#else	
	DEBUG_MESSAGE ("netload_applet v" VERSION ", Linux, started.\n");
#endif

	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
	textdomain (PACKAGE);

	device_list = get_available_devices ();

	gtk_init(&argc, &argv);

	/*
	 * create applet
	 */
	DEBUG_MESSAGE ("main: creating applet.\n");
	applet_widget_init("netload_applet", VERSION, argc, argv,
			   NULL, 0, NULL);
	applet = applet_widget_new("netload_applet");
	if (!applet)
		g_error("Can't create applet!\n");

	gtk_signal_connect(GTK_OBJECT (applet), "save_session",
			   GTK_SIGNAL_FUNC (session_save_handler), NULL);

	gtk_signal_connect(GTK_OBJECT (applet), "destroy",
			   GTK_SIGNAL_FUNC (destroy_handler_main), NULL);

	/*
	 * add menu items
	 */
	DEBUG_MESSAGE ("main: adding menu items.\n");
	applet_widget_register_stock_callback(APPLET_WIDGET(applet),
					      "about",
					      GNOME_STOCK_MENU_ABOUT,
					      _("About..."),
					      &about_handler,
					      NULL);
	applet_widget_register_stock_callback(APPLET_WIDGET(applet),
					      "properties",
					      GNOME_STOCK_MENU_PREF,
					      _("Properties..."),
					      &pref_handler,
					      NULL);

	/*
	 * initialize display scheme
	 */
	DEBUG_MESSAGE ("main: initializing display scheme.\n");
	if (!get_config ())
		set_default_display_scheme ();
	init_display_scheme ();

	/*
	 * add drawing area
	 */
	DEBUG_MESSAGE ("main: adding drawing area.\n");
	draw = gtk_drawing_area_new();
	gtk_drawing_area_size(GTK_DRAWING_AREA (draw), display_scheme.width, display_scheme.height);
	gtk_signal_connect(GTK_OBJECT (draw), "expose_event",
			   GTK_SIGNAL_FUNC (redraw_handler), NULL);
         
	applet_widget_add(APPLET_WIDGET (applet), draw);

#ifdef HAVE_PANEL_PIXEL_SIZE
	DEBUG_MESSAGE ("main: adding change_pixel_size handler.\n");
	gtk_signal_connect (GTK_OBJECT (applet), "change_pixel_size",
			    GTK_SIGNAL_FUNC (change_pixel_size_handler),
			    NULL);
#endif

	/*
	 * display applet
	 */
	gtk_widget_show(draw);
	gtk_widget_show(applet);

	/*
	 * create Graphics Context
	 */
	gc = gdk_gc_new(draw->window);
	if (!gc)
		g_error ("Couldn't create graphics context!\n");

	/*
	 * add timeout
	 */
	timeout_id = gtk_timeout_add(display_scheme.timeout, timeout_handler, NULL);

	applet_widget_gtk_main();

	return 0;
}
