/*
 * netload_applet Main header file
 * Copyright (C) 2001 Jan Oberlnder <mindriot@gmx.net>
 *
 * This file is part of netload_applet.
 *
 * netload_applet is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: netload_applet.h,v 1.1.1.1 2001/03/08 03:01:59 mindriot Exp $
 */

#ifndef NETLOAD_APPLET_H
#define NETLOAD_APPLET_H

#include <config.h>
#include <gnome.h>
#include <applet-widget.h>
#include <libgnome/gnome-i18n.h>

/*
 * debug messages
 */
#if (DEBUG == 1)
#define DEBUG_MESSAGE(message) g_print (message)
#else
#define DEBUG_MESSAGE(message)
#endif

/*
 * Position encoding for different elemnts shown in the applet.
 * use POS_HORIZ and POS_VERT to filter horizontal/vertical component.
 */
typedef enum {
	POS_LEFT   = 0,
	POS_CENTER = 1,
	POS_RIGHT  = 2,
	POS_HORIZ  = 3,
	POS_TOP    = 0 << 2,
	POS_MIDDLE = 1 << 2,
	POS_BOTTOM = 2 << 2,
	POS_VERT   = 3 << 2
} ItemPosition;

/*
 * Different graph styles
 */
typedef enum {
	GRAPH_BARCHART = 0,
	GRAPH_LINECHART = 1
} GraphStyle;

/*
 * Specifies the Z-Order of the two Graphs (i.e., which one is drawn on top)
 */
typedef enum {
	RX_ON_TOP,
	TX_ON_TOP
} GraphOrder;

/*
 * The complete display scheme for the applet.
 * Stores all color settings for the different elements and the position of
 * the different text elements (top/mid/bottom, left/center/right) as well
 * as font settings. You need only set the font_name fields, upon initialization
 * the program will fill in the GdkFont fields itself.
 * The applet is surrounded by a one-pixel thick frame. Use top_edge_color and
 * bottom_edge_color to define the top-left and bottom-right part's color. That way,
 * by setting top_edge_color to dark gray and bottom_edge_color to white you can
 * create a 3-D looking frame.
 * Also stores the device name, the graph styles (barchart/linechart), and
 * the scroll speed (usually 1 new value per second).
 * You can specify the applet width and height with the corresponding fields; setting
 * fixed_width or fixed_height to FALSE means the applet uses the given panel size
 * (as of gnome 1.2). By default it will use a panel size of 48x48; the actual width
 * and height used to draw is the here given width and height - 2 (because of the border).
 */
typedef struct {
	GdkFont *rx_load_font;
	GdkFont *tx_load_font;
	GdkFont *max_load_font;
	GdkFont *dev_font;

	gchar *rx_load_font_name;
	gchar *tx_load_font_name;
	gchar *max_load_font_name;
	gchar *dev_font_name;

	GdkColor background_color;
	GdkColor rx_graph_color;
	GdkColor tx_graph_color;
	GdkColor rx_avg_color;
	GdkColor tx_avg_color;
	GdkColor rx_load_color;
	GdkColor tx_load_color;
	GdkColor max_load_color;
	GdkColor dev_color;
	GdkColor top_edge_color;
	GdkColor bottom_edge_color;

	ItemPosition rx_load_position;
	ItemPosition tx_load_position;
	ItemPosition max_load_position;
	ItemPosition dev_position;

	gboolean show_rx_graph;
	gboolean show_tx_graph;
	gboolean show_rx_avg;
	gboolean show_tx_avg;
	gboolean show_rx_load;
	gboolean show_tx_load;
	gboolean show_max_load;
	gboolean show_dev;

	GraphStyle rx_graph_style;
	GraphStyle tx_graph_style;
	GraphOrder graph_order;

	guint32 width;
	guint32 height;
	gboolean fixed_width;
	gboolean fixed_height;

	gchar *device;
	guint32 timeout;
} DisplayScheme;

#endif
